Contributors
============

* Alexis Metaireau <alexis@mozilla.com>
* Andy McKay <amckay@mozilla.com>
* Balthazar Rouberol <br@imap.cc>
* Dan Phrawzty <phrawzty+github@gmail.com>
* Éric Lemoine <eric.lemoine@gmail.com>
* Hiromipaw <silvia@nopressure.co.uk>
* Mathieu Leplatre <mathieu@mozilla.com>
* Michiel de Jong <michiel@unhosted.org>
* Nicolas Perriault <nperriault@mozilla.com>
* Rémy Hubscher <rhubscher@mozilla.com>
* Tarek Ziade <tarek@mozilla.com>
